Name:		libssh2
Version:	1.10.0
Release:	6
Summary:	A library implementing the SSH2 protocol
License:	BSD
URL:		https://www.libssh2.org/
Source0:	https://libssh2.org/download/libssh2-%{version}.tar.gz

Patch0:		backport-RSA-SHA2-256-512-key-upgrade-support-RFC-8332.patch
Patch1:		backport-sftp-Prevent-files-from-being-skipped-if-the.patch
Patch2:		backport-Support-rsa-sha2-agent-flags.patch
Patch3:		backport-Fix-a-memcmp-errors-in-code-that-was-changed-from-me.patch
Patch4:		backport-Legacy-Agent-support-for-rsa2-key-upgrading-downgrad.patch
Patch5:		backport-free-RSA2-related-memory-664.patch
Patch6:		backport-NULL-terminate-server_sign_algorithms-string-669.patch
Patch7:		backport-Skip-leading-r-and-n-characters-in-banner_receive-76.patch
Patch8:		backport-src-add-strict-KEX-to-fix-CVE-2023-48795-Terrapin-At.patch

BuildRequires:	coreutils findutils /usr/bin/man zlib-devel
BuildRequires:	gcc make sed openssl-devel > 1:1.0.1 openssh-server
BuildRequires:	glibc-langpack-en groff

%description
libssh2 is a library implementing the SSH2 protocol as defined by
Internet Drafts: SECSH-TRANS(22), SECSH-USERAUTH(25),
SECSH-CONNECTION(23), SECSH-ARCH(20), SECSH-FILEXFER(06)*,
SECSH-DHGEX(04), and SECSH-NUMBERS(10).

%package	devel
Summary:	Development files for libssh2
Requires:	%{name}%{?_isa} = %{version}-%{release} pkgconfig

%description	devel
The libssh2-devel package contains libraries and header files for
developing applications that use libssh2.

%package_help

%prep
%autosetup -n %{name}-%{version} -p1

sed -i s/4711/47%{__isa_bits}/ tests/ssh2.{c,sh}

%build
%configure --disable-silent-rules --enable-shared
%make_build

%install
%make_install
%delete_la

make -C example clean
rm -rf example/.deps
find example/ -type f '(' -name '*.am' -o -name '*.in' ')' -delete

mv -v example example.%{_arch}

%check
echo "Running tests for %{_arch}"
if [ ! -c /dev/tty ]; then
	echo Skipping SSH test due to missing /dev/tty
	echo "exit 0" > tests/ssh2.sh
fi
%ifarch %{sparc} %{arm}
echo Skipping SSH test on sparc/arm
echo "exit 0" > tests/ssh2.sh
%endif
%ifarch ppc %{power64} aarch64
echo "Skipping mansyntax test on PPC* and aarch64"
echo "exit 0" > tests/mansyntax.sh
%endif
LC_ALL=en_US.UTF-8 make -C tests check

%ldconfig_scriptlets

%files
%defattr(-,root,root)
%{!?_licensedir:%global license %%doc}
%doc docs/AUTHORS NEWS README RELEASE-NOTES
%license COPYING
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%doc example.%{_arch}/
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/*.a
%{_libdir}/pkgconfig/*.pc

%files help
%defattr(-,root,root)
%doc docs/BINDINGS docs/HACKING docs/TODO NEWS
%{_mandir}/man3/libssh2_*.3*

%changelog
* Wed Apr 3 2024 renmingshuai <renmingshuai@huawei.com> - 1.10.0-6
- Type:CVE
- ID:CVE-2023-48795
- SUG:NA
- DESC:fix CVE-2023-48795

* Tue Mar 28 2023 renmingshuai <renmingshuai@huawei.com> - 1.10.0-5
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:backport some upstream patches

* Thu Feb 16 2023 renmingshuai <renmingshuai@huawei.com> - 1.10.0-4
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:Support rsa-sha2 agent flags

* Tue Oct 18 2022 renmingshuai <renmingshuai@huawei.com> - 1.10.0-3
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:sftp: Prevent files from being skipped

* Fri Jan 07 2022 xingwei <xingwei14@huawei.com> - 1.10.0-2
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:RSA SHA2 256/512 key upgrade support RFC 8332 

* Fri Dec 03 2021 gaihuiying <gaihuiying1@huawei.com> - 1.10.0-1
- Type:requirement
- ID:NA
- SUG:NA
- DESC:update libssh2 to 1.10.0

* Thu Sep 24 2020 yuboyun <yuboyun@huawei.com> - 1.9.0-6
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:fix heap-buffer-overflow in _libssh2_ntohu32

* Fri Sep 11 2020 gaihuiying <gaihuiying1@huawei.com> - 1.9.0-5
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:fix to use better bounds check

* Thu Jun 4 2020 songzifeng<songzifeng1@huawei.com> - 1.9.0-4
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:fix heap buffer overflow in kex.c

* Sat May 30 2020 songzifeng<songzifeng1@huawei.com> - 1.9.0-3
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:fix use of uninitialized value in transport.c

* Sat Dec 21 2019 openEuler Buildteam <buildteam@openeuler.org> - 1.9.0-2
- Type:bugfix
- Id:NA
- SUG:NA
- DESC: add patches

* Sun Sep 15 2019 openEuler Buildteam <buildteam@openeuler.org> - 1.9.0-1
- Package init
